{%- extends "default/edit/open.mkd" -%}
{%- block header -%}
  {%- if not local -%}
{{ comment_char }} NOTE: This command is for reporting bugs against hubugs, if that is not your
{{ comment_char }} intention close this file without saving to cancel!
  {%- endif -%}
{%- endblock -%}

{%- block inset %}
---

Information useful for `hubugs` bug reports, *please* do not remove any of the
data below.

* `hubugs` version: {{ version }}
* Dependency versions:
{%- for key, value in versions | dictsort %}
    * `{{ key }}`: {{ value }}
{%- endfor %}

* System:
    * `Python`: {{ sys.version }}
    * Operating system: {{ sys.platform }}
    * Certificates: {{ certificates }}
{% endblock -%}
